@@ -2,8 +2,8 @@ import re
 import sys
 import time
 import unicodedata
-import collections
 import functools
+import hmac
 import logging
 
 import six
@@ -110,7 +110,7 @@ def sanitize_redirect(hosts, redirect_to):
 
 def user_is_authenticated(user):
     if user and hasattr(user, 'is_authenticated'):
-        if isinstance(user.is_authenticated, collections.Callable):
+        if callable(user.is_authenticated):
             authenticated = user.is_authenticated()
         else:
             authenticated = user.is_authenticated
@@ -123,7 +123,7 @@ def user_is_authenticated(user):
 
 def user_is_active(user):
     if user and hasattr(user, 'is_active'):
-        if isinstance(user.is_active, collections.Callable):
+        if callable(user.is_active):
             is_active = user.is_active()
         else:
             is_active = user.is_active
@@ -218,21 +218,12 @@ def build_absolute_uri(host_url, path=None):
 
 
 def constant_time_compare(val1, val2):
-    """
-    Returns True if the two strings are equal, False otherwise.
-    The time taken is independent of the number of characters that match.
-    This code was borrowed from Django 1.5.4-final
-    """
-    if len(val1) != len(val2):
-        return False
-    result = 0
-    if six.PY3 and isinstance(val1, bytes) and isinstance(val2, bytes):
-        for x, y in zip(val1, val2):
-            result |= x ^ y
-    else:
-        for x, y in zip(val1, val2):
-            result |= ord(x) ^ ord(y)
-    return result == 0
+    """Compare two values and prevent timing attacks for cryptographic use."""
+    if isinstance(val1, six.text_type):
+        val1 = val1.encode('utf-8')
+    if isinstance(val2, six.text_type):
+        val2 = val2.encode('utf-8')
+    return hmac.compare_digest(val1, val2)
 
 
 def is_url(value):
